@@ -63,7 +63,6 @@ class Products extends CGExtensions
   var $_hierarchy_cache;
   var $_category_cache;
   var $_admin_loaded;
-  var $_common_loaded;
 
   public function __construct()
   {
@@ -72,10 +71,10 @@ class Products extends CGExtensions
 	$this->_hierarchy_cache = array();
 	$this->_category_cache = array();
 	$this->_admin_loaded = false;
-	$this->_common_loaded = false;
 
-    global $gCms;
-    $smarty =& $gCms->GetSmarty();
+	$this->AddImageDir('icons');
+
+    $smarty = cmsms()->GetSmarty();
 	$smarty->register_function('products_getcategory',
 							   array($this,'_smarty_products_getcategory'));
   }
@@ -92,7 +91,7 @@ class Products extends CGExtensions
 
   function GetDependencies()
   {
-	return array('CGExtensions'=>'1.19.6',
+	return array('CGExtensions'=>'1.21',
 		     'CGSimpleSmarty'=>'1.4.4');
   }
 
@@ -118,7 +117,7 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.8.7';
+	return '2.9';
   }
 
   function MinimumCMSVersion()
@@ -157,8 +156,6 @@ EOT;
 
   function SetParameters()
   {
-	$this->AddImageDir('icons');
-
 	$this->RegisterModulePlugin();
 	$this->RestrictUnknownParams();
 
@@ -337,20 +334,8 @@ EOT;
 	  }
   }
 
-  function _load_common()
-  {
-	if( !$this->_common_loaded )
-	  {
-		require_once(dirname(__FILE__).'/functions.common_tools.php');
-		$this->_common_loaded = true;
-	  }
-  }
-
-// public static function load_ops()
-// {
-//   require_once(dirname(__FILE__).'/lib/class.product_ops.php');
-// }
 
+  // deprecated
   function GetTypesDropdown( $id, $name, $selected = '', $addtext = '', $selectone = false )
   {
 	$this->_load_admin();
@@ -358,11 +343,12 @@ EOT;
   }
 	
 
+  // deprecated
   function GetCategory($category_id,$full = false)
   {
 	global $gCms;
 	$db =& $gCms->GetDb();
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 
 	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_categories WHERE id = ?';
     $query2 = 'SELECT * FROM '.cms_db_prefix().'module_products_category_fields 
@@ -390,11 +376,12 @@ EOT;
   }
 
 
+  // deprecated
   function GetCategories($full = false)
   {
 	global $gCms;
 	$db =& $gCms->GetDB();
-	$config =& $gCms->GetConfig();
+	$config = $gCms->GetConfig();
 		
 	if( count($this->_category_cache) )
 	  {
@@ -432,7 +419,8 @@ EOT;
 	return $entryarray;
   }
 
-	
+
+  // deprecated
   function GetCategoriesForProduct($product,$brief = false,$full = false)
   {
 	$entryarray = array();
@@ -485,6 +473,7 @@ EOT;
   }
 	
 
+  // deprecated
   function GetFieldDefs($admin = false,$public = true)
   {
 	$entryarray = array();
@@ -530,7 +519,8 @@ EOT;
 	return $entryarray;
   }
 
-	
+
+  // deprecated, move to class
   function GetFieldDefsForProduct($id,$admin = false,$public = true)
   {
 	$entryarray = array();
@@ -589,6 +579,7 @@ EOT;
   }
 
 
+  // deprecated ... move to class
   function GetSearchableText($product_id)
   {
 	// the product name, the description, and all data from
@@ -625,6 +616,8 @@ EOT;
 	return $results;
   }
 
+
+  // deprecated
   function GetProductNameFromId( $id )
   {
 	if( !isset( $this->_product_cache[$id] ) )
@@ -636,6 +629,7 @@ EOT;
   }
 
 
+  // depreacated
   function is_taxable($product_id)
   {
     $tmp = $this->GetProduct($product_id);
@@ -650,6 +644,7 @@ EOT;
   }
 
 
+  // deprecated
   function GetProduct( $id )
   {
 	if( !isset($this->_product_cache[$id]) )
@@ -666,6 +661,7 @@ EOT;
   }
 
 
+  // deprecated
   function GetProductAttributes($product_id)
   {
 	$results = array();
@@ -681,6 +677,7 @@ EOT;
   }
 
 
+  // deprecated
   function GetProductAttributeDataComplete($product_id)
   {
 	$db =& $this->GetDb();
@@ -717,6 +714,7 @@ EOT;
   }
 
 
+  // deprecated
   static public function GetProductIdsFromCategories($str,$delim = ',')
   {
 	if( empty($str) ) return FALSE;
@@ -742,6 +740,7 @@ EOT;
   }
 
 
+  // deprecated 
   static public function GetProductIdsFromHierarchy($hier_str,$delim = ' | ')
   {
 	if( empty($hier_str) ) return FALSE;
@@ -782,6 +781,7 @@ EOT;
   }
 
 
+  // deprecated, move to ops
   function UpdateHierarchyPositions()
   {
 	$this->_load_admin();
@@ -789,6 +789,7 @@ EOT;
   }
 
 
+  // deprecated, move to ops
   function BuildHierarchyList()
   {
 	$this->_load_admin();
@@ -796,6 +797,7 @@ EOT;
   }
 
 
+  // deprecated, move to ops
   function CreateHierarchyDropdown($id,$name,$selectedvalue)
   {
 	$this->_load_admin();
@@ -803,6 +805,7 @@ EOT;
   }
 
 
+  // deprecated... use get_pretty_url
   function CreatePrettyLink($id, $action, $returnid='', $contents='', $params=array(), 
 							$warn_message='', $onlyhref=false, $inline=false, $addtext='', 
 							$targetcontentonly=false, $prettyurl='')
@@ -900,34 +903,25 @@ EOT;
 	return products_ProcessImage($this,$srcname,$wmlocation);
   }
 
-  function &GetCartModule()
-  {
-	$cartmod = $this->GetPreference('cartmodule','');
-	if( empty($cartmod) || $cartmod == -1 ) return FALSE;
-	$mod =& $this->GetModuleInstance($cartmod);
-	if( !is_object($mod) ) return FALSE;
-	return $mod;
-  }
-
 
+  // deprecated
   function GetHierarchyInfo($hierarchy_id)
   {
-	$this->_load_common();
-	return products_GetHierarchyInfo($this,$hierarchy_id);
+	return hierarchy_ops::get_hierarchy_info($hierarchy_id);
   }
 
 
+  // deprecated
   function GetHierarchyPath($hiearchy_id)
   {
-	$this->_load_common();
-	return products_GetHierarchyPath($this,$hierarchy_id);
+	return hierarchy_ops::get_hierarchy_path($hierarchy_id);
   }
 
 
+  // deprecated
   function GetProductHierarchyPath($productid)
   {
-	$this->_load_common();
-	return products_GetProductHierarchyPath($this,$productid);
+	return product_ops::get_product_hierarchy_path($productid);
   }
 
 
