@@ -265,7 +265,7 @@ if( $count )
     if( !$dbresult ) return FALSE;
 
     global $gCms;
-    $config =& $gCms->GetConfig();
+    $config = $gCms->GetConfig();
     $parms = array();
     if( isset($params['detailtemplate']) )
       {
@@ -288,6 +288,10 @@ if( $count )
 	$onerow->file_location = $config['uploads_url'].'/'.$this->GetName().'/product_'.$row['id'];
 	$onerow->details = $row['details'];
 
+	// hierarchy information
+	$onerow->hierarchy_id = product_ops::get_product_hierarchy_id($params['productid']);
+	$onerow->breadcrumb = product_ops::create_hierarchy_breadcrumb($id,$params['productid'],$returnid);
+
 	// add custom fields
 	$fielddefs = $this->GetFieldDefsForProduct($row['id'],true,true);
 	$fields = array();
