@@ -116,8 +116,7 @@ $smarty->assign('input_autopreviewimg',
 $smarty->assign('auto_previewimg_size',
 		$this->GetPreference('auto_previewimg_size',150));
 
-$smarty->assign('urlprefix',
-		$this->GetPreference('urlprefix','products'));
+$smarty->assign('urlprefix',$this->GetPreference('urlprefix',''));
 
 $opts = array();
 $opts[$this->Lang('none')] = 'none';
