@@ -65,11 +65,14 @@ $field_names = array();
 //
 // Get preferences
 //
-$hierarchy = get_preference($uid,'products_sel_hierarchy','');
-$children  = get_preference($uid,'products_sel_children',0);
-$pagelimit = get_preference($uid,'products_sel_pagelimit',25);
-$sortby    = get_preference($uid,'products_sel_sortby','create_date');
-$sortorder = get_preference($uid,'products_sel_sortorder','desc');
+$hierarchy  = get_preference($uid,'products_sel_hierarchy','');
+$children   = get_preference($uid,'products_sel_children',0);
+$pagelimit  = get_preference($uid,'products_sel_pagelimit',25);
+$sortby     = get_preference($uid,'products_sel_sortby','create_date');
+$sortorder  = get_preference($uid,'products_sel_sortorder','desc');
+$categories = '';
+$tmp= get_preference($uid,'products_sel_categories','');
+if( !empty($tmp) ) $categories = explode(',',$categories);
 $custom_fields = '';
 $tmp = get_preference('uid','products_sel_customfields','');
 if( !empty($tmp) ) $custom_fields = explode(',',$tmp);
@@ -101,6 +104,14 @@ if( isset($params['submit']) )
       {
 	$custom_fields = array();
       }
+    if( isset($params['categories']) )
+      {
+	$categories = $params['categories'];
+      }
+    else
+      {
+	$categories = array();
+      }
 
     // store them as user preferences
     set_preference($uid,'products_sel_hierarchy',$hierarchy);
@@ -109,11 +120,25 @@ if( isset($params['submit']) )
     set_preference($uid,'products_sel_sortby',$sortby);
     set_preference($uid,'products_sel_sortorder',$sortorder);
     set_preference($uid,'products_sel_customfields',implode(',',$custom_fields));
+    set_preference($uid,'products_sel_categories',implode(',',$categories));
   }
 
 //
 // Begin the form
 //
+{
+  $tmp = $this->GetCategories();
+  if( is_array($tmp) )
+    {
+      $category_list = array();
+      for( $i = 0; $i < count($tmp); $i++ )
+	{
+	  $category_list[$tmp[$i]->id] = $tmp[$i]->name;
+	}
+      $smarty->assign('category_list',$category_list);
+    }
+}
+
 $fielddefs = $this->GetFieldDefs();
 foreach( $fielddefs as $onedef )
 {
@@ -166,6 +191,10 @@ if( count($fields_viewable) )
     $smarty->assign('fields_viewable',$fields_viewable);
     $smarty->assign('field_names',$field_names);
   }
+if( count($categories) )
+  {
+    $smarty->assign('categories',$categories);
+  }
 $smarty->assign('custom_fields',$custom_fields);
 $smarty->assign('formstart',$this->CGCreateFormStart($id,'defaultadmin'));
 $smarty->assign('formend',$this->CreateFormEnd());
@@ -217,6 +246,13 @@ if( !empty($hierarchy) )
 	$qparms[] = $long_name;
       }
   }
+if( is_array($categories) && count($categories) > 0 )
+  {
+    $joins[] = 'LEFT JOIN '.cms_db_prefix().'module_products_product_categories pc
+                  ON p.id = pc.product_id';
+    $where[] = 'pc.category_id IN ('.implode(',',$categories).')';
+  }
+
 // handle funky custom field sort orders
 if( startswith($sortby,'-F-') )
   {
@@ -260,21 +296,21 @@ $smarty->assign('pagecount',$pagecount);
 $smarty->assign('totalrows',$totalcount);
 if( $pagenumber > 1 )
   {
-    $params['pagenumber'] = 1;
+    $parms = array('pagenumber'=>1);
     $smarty->assign('firstpage_url',
-		    $this->CreateURL($id,'defaultadmin','',$params));
-    $params['pagenumber'] = $pagenumber - 1;
+		    $this->CreateURL($id,'defaultadmin','',$parms));
+    $parms = array('pagenumber'=>$pagenumber -1);
     $smarty->assign('prevpage_url',
-		    $this->CreateURL($id,'defaultadmin','',$params));
+		    $this->CreateURL($id,'defaultadmin','',$parms));
   }
 if( $pagenumber < $pagecount )
   {
-    $params['pagenumber'] = $pagenumber + 1;
+    $parms = array('pagenumber'=>$pagenumber + 1);
     $smarty->assign('nextpage_url',
-		    $this->CreateURL($id,'defaultadmin','',$params));
-    $params['pagenumber'] = $pagecount;
+		    $this->CreateURL($id,'defaultadmin','',$parms));
+    $parms = array('pagenumber'=>$pagecount);
     $smarty->assign('lastpage_url',
-		    $this->CreateURL($id,'defaultadmin','',$params));
+		    $this->CreateURL($id,'defaultadmin','',$parms));
   }
 $entryarray = array();	
 $dbresult = $db->SelectLimit($query1,$pagelimit,$startelement,$qparms);
