@@ -44,9 +44,11 @@ $lang['categorylisttemplates'] = 'CategoryList Templates';
 $lang['categorylisttemplate_addedit'] = 'Add/Edit A CategoryList Template';
 $lang['centimeters'] = 'Centimeters';
 $lang['checkbox'] = 'Checkbox';
+$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any products that are using this node will be set to no hierarchy';
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
+$lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category']  = 'Copy Category';
 $lang['createddate'] = 'Created Date';
 $lang['current_value'] = 'Current Value';
@@ -63,6 +65,7 @@ $lang['delete_attribset'] = 'Delete Attribute';
 $lang['delete_hierarchy_item'] = 'Delete Hierarchy Item';
 $lang['descending'] = 'Descending';
 $lang['description'] = 'Description';
+$lang['destination'] = 'Destination';
 $lang['details'] = 'Details';
 $lang['detailtemplates'] = 'Detail Templates';
 $lang['detailtemplate_addedit'] = 'Add/Edit A Detail Template';
@@ -79,7 +82,7 @@ $lang['edit_attribsets'] = 'Edit Attribute Sets';
 $lang['edit_attribsets_for'] = 'Edit Attribute Sets For';
 $lang['edit_attributes'] = 'Edit Attributes';
 $lang['edit_category'] = 'Edit Category';
-$lang['edit_category_fields'] = 'Edit Category Fields';
+$lang['edit_category_fields'] = 'Edit Category Fields for &quot;%s&quot;';
 $lang['edit_hierarchy_item'] = 'Edit Hierarchy Item';
 $lang['error_attribset_exists'] = 'An attribute with that name already exists';
 $lang['error_duplicate_sku'] = 'Duplicate SKU value found';
@@ -89,6 +92,7 @@ $lang['error_filenotfound'] = 'File Not Found';
 $lang['error_fileopen'] = 'Problem opening file %s';
 $lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it\'s own parent)';
 $lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
+$lang['error_invalid_value'] = 'Invalid value specified';
 $lang['error_missingparam'] = 'A required parameter is missing or invalid';
 $lang['error_nameused'] = 'An item by that name is already in use';
 $lang['error_nofieldtype'] = 'Please select a field type';
@@ -215,9 +219,11 @@ $lang['inches'] = 'Inches';
 $lang['include_children'] = 'Include Children?';
 $lang['info_alnumonly'] = 'Only alphanumeric characters. No whitespace, quotes, or non letter/number combinations';
 $lang['info_attribtemplate'] = 'Possible variables are: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
+$lang['info_attributes_copied'] = 'Attributes Copied';
 $lang['info_autowatermark'] = 'Watermark settings are taken from the CGExtensions Module';
 $lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
 $lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the product detail and summary displays';
+$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
 $lang['info_createfields'] = 'Create unknown product fields automatically? <em>(They will be created as text fields)</em>';
 $lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
 $lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
@@ -336,6 +342,8 @@ $lang['product'] = 'Product';
 $lang['productname'] = 'Product Name';
 $lang['products'] = 'Products';
 $lang['product_detail_settings'] = 'Product Detail Settings';
+$lang['product_editing_settings'] = 'Product Editing Settings';
+$lang['product_summary_settings'] = 'Product Summary Settings';
 $lang['product_hierarchy'] = 'Product Hierarchy';
 $lang['product_manager'] = 'Product Manager';
 $lang['progress'] = 'Progress';
@@ -410,6 +418,7 @@ $lang['select_one'] = 'Select One';
 $lang['sku'] = 'SKU';
 $lang['sort_by'] = 'Sort By';
 $lang['sort_order'] = 'Sort Order';
+$lang['source'] = 'Source';
 $lang['status'] = 'Status';
 $lang['submit'] = 'Submit';
 $lang['subscription'] = 'Subscription';
