@@ -1,4 +1,7 @@
 <?php
+$lang['abbr_length'] = 'l';
+$lang['abbr_width'] = 'L';
+$lang['abbr_height'] = 'H';
 $lang['add'] = 'Ajouter';
 $lang['addcategory'] = 'Ajouter une cat&eacute;gorie';
 $lang['addfielddef'] = 'Ajouter un champ';
@@ -18,7 +21,9 @@ $lang['align_mr'] = 'Milieu droit';
 $lang['align_ll'] = 'Bas gauche';
 $lang['align_lc'] = 'Bas centre';
 $lang['align_lr'] = 'Bas droit';
+$lang['all'] = 'Tous';
 $lang['allcategories'] = 'Toutes les cat&eacute;gories';
+$lang['any'] = 'Aucun';
 $lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r?';
 $lang['areyousure_deleteproduct'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ce produit, et toute l&#039;information l&#039;accompagnant ?';
 $lang['ascending'] = 'Ascendant';
@@ -32,6 +37,7 @@ $lang['category'] = 'Cat&eacute;gorie';
 $lang['categoryexists'] = 'Une cat&eacute;gorie du m&ecirc;me nom existe d&eacute;j&agrave;';
 $lang['categorylisttemplates'] = 'Gabarits de la liste des cat&eacute;gories';
 $lang['categorylisttemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit de liste de cat&eacute;gories';
+$lang['centimeters'] = 'Centim&egrave;tres';
 $lang['checkbox'] = 'Case &agrave; cocher';
 $lang['confirm_delete_hierarchy_node'] = 'Confirmez-vous la suppression de cet &eacute;l&eacute;ment ? Tous les produits qui l&#039;utilisent ne figureront plus dans la hi&eacute;rarchie.';
 $lang['confirm_import'] = 'Voulez-vous r&eacute;ellement effectuer cette action ?\n\nDes param&egrave;tres incorrects ou un fichier de configuration invalide peuvent corrompre le catalogue de produits et le rendre inutilisable.';
@@ -51,6 +57,7 @@ $lang['description'] = 'Un module pour g&eacute;rer un catalogue de produits, le
 $lang['details'] = 'D&eacute;tails';
 $lang['detailtemplates'] = 'Gabarits d&eacute;tails';
 $lang['detailtemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit d&eacute;tails';
+$lang['dimensions'] = 'Dimensions';
 $lang['disabled'] = 'D&eacute;sactiv&eacute;';
 $lang['draft'] = '&Eacute;bauche';
 $lang['dropdown'] = 'Menu d&eacute;roulant';
@@ -64,6 +71,7 @@ $lang['edit_category'] = 'Editer la cat&eacute;gorie';
 $lang['edit_category_fields'] = 'Editer les champs de la cat&eacute;gorie';
 $lang['edit_hierarchy_item'] = 'Editer l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie';
 $lang['error_attribset_exists'] = 'Il y a d&eacute;j&agrave; un attribut du m&ecirc;me nom';
+$lang['error_duplicate_sku'] = 'Plusieurs Valeurs SKU identiques trouv&eacute;es';
 $lang['error_fieldvalue_empty'] = 'Une valeur doit &ecirc;tre indiqu&eacute;e';
 $lang['error_fileformat'] = 'Probl&egrave;me de format de fichier';
 $lang['error_filenotfound'] = 'Fichier introuvable';
@@ -74,10 +82,17 @@ $lang['error_missingparam'] = 'Un param&egrave;tre requis est manquant ou invali
 $lang['error_nameused'] = 'Un &eacute;l&eacute;ment portant ce nom existe d&eacute;j&agrave;';
 $lang['error_nofieldtype'] = 'Choisisser le type du champ';
 $lang['error_noname'] = 'Un nom doit &ecirc;tre indiqu&eacute;';
+$lang['error_onesubscriptionfield'] = 'Un seul champs de souscription est autoris&eacute;';
 $lang['error_permissiondenied'] = 'Permission refus&eacute;e';
+$lang['error_product_aliasused'] = 'L&#039;alias sp&eacute;cifi&eacute; est d&eacute;j&agrave; utilis&eacute;';
 $lang['error_product_nameused'] = 'Un produit portant ce nom existe d&eacute;j&agrave;';
+$lang['error_product_notfound'] = 'Le produit d&eacute;sir&eacute; n&#039;a pas pu &ecirc;tre retrouv&eacute;';
+$lang['error_product_skuused'] = 'Cette valeur SKU est d&eacute;j&agrave; utilis&eacute;e par un autre produit';
 $lang['error_price_adjustment'] = 'La valeur d&#039;ajustement du prix est invalide pour l&#039;objet %s';
 $lang['error_upload_failed'] = 'L&#039;envoi du fichier a &eacute;chou&eacute;: %s';
+$lang['expire_six_months'] = 'Apr&egrave;s Six Mois';
+$lang['expire_one_year'] = 'Apr&egrave;s Un An';
+$lang['expire_two_year'] = 'Apr&egrave;s Deux Ans';
 $lang['extra1'] = 'Champ suppl&eacute;mentaire 1';
 $lang['extra2'] = 'Champ suppl&eacute;mentaire 2';
 $lang['field'] = 'Champ';
@@ -153,8 +168,10 @@ $lang['id'] = 'Id ';
 $lang['imagetext'] = 'Image ';
 $lang['image_handling_settings'] = 'Param&egrave;tres de manipulation des images';
 $lang['import_from_csv'] = 'Importer les produits depuis un fichier CSV';
+$lang['inches'] = 'Pouces';
 $lang['include_children'] = 'Avec les descendants ?';
 $lang['info_alnumonly'] = 'Caract&egrave;res alphanum&eacute;riques uniquement. Pas d&#039;espaces, de guillemets ou de combinaisons autres que lettres et chiffres.';
+$lang['info_attribtemplate'] = 'Les variables possibles sont : {$attrib_text},{$attrib_adjust},{$currency_symbol}';
 $lang['info_autowatermark'] = 'La configuration des filigranes est celle du module CGExtensions';
 $lang['info_batchsize'] = 'Indiquez le nombre de lignes &agrave; traiter &agrave; chaque it&eacute;ration. D&egrave;s qu&#039;une it&eacute;ration est termin&eacute;e, le syst&egrave;me d&#039;importation d&eacute;marre la suivante. Si des probl&egrave;mes de m&eacute;moire ou de temps d&#039;ex&eacute;cution se produisent, r&eacute;duisez cette valeur, ou consultez le fournisseur de votre h&eacute;bergement.';
 $lang['info_cart_module_params'] = 'Ces param&egrave;tres sont pass&eacute;s au module panier s&eacute;lectionn&eacute;, &agrave; partir de la description et du r&eacute;sum&eacute; du produit.';
@@ -170,6 +187,7 @@ $lang['info_handleimages'] = 'Lors de l&#039;importation, si un nom de fichier i
 $lang['info_imagepath'] = 'Chemin (relatif au r&eacute;pertoire uploads) des images r&eacute;f&eacute;renc&eacute;es par le fichier import&eacute; ';
 $lang['info_import_test_passed'] = 'Apr&egrave;s un examen pr&eacute;liminaire, le fichier semble correct.<br/>Cependant, il se peut qu&#039;il contienne tout de m&ecirc;me des erreurs qui ne pourront &ecirc;tre d&eacute;tect&eacute;es que lors de l&#039;importation.';
 $lang['info_price_adjustment'] = 'Les valeurs valides sont +-*#.##';
+$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Les champs publics sont visibles par les utilisateurs.';
 $lang['label'] = '&Eacute;tiquette';
 $lang['label_skip'] = 'Ignorer';
@@ -180,6 +198,8 @@ $lang['logotext'] = 'Logo ';
 $lang['maxlength'] = 'Longeur Maximale <em>(applicable seulement aux champs textbox)</em>';
 $lang['modifieddate'] = 'Date de modification';
 $lang['module_description'] = 'Un module de gestion d&#039;un catalogue de produits, de leurs prix, images, etc. Permet aussi aux utilisateurs de remplir un panier d&#039;achat.';
+$lang['move_down'] = 'Descendre';
+$lang['move_up'] = 'Remonter';
 $lang['name'] = 'Nom';
 $lang['needpermission'] = 'Vous n&#039;avez pas la permission requise&nbsp;: %s';
 $lang['new_category_name'] = 'Nouveau nom de cat&eacute;gorie';
@@ -199,14 +219,22 @@ $lang['param_action'] = 'Sp&eacute;cifie le comportement du module. Les valeurs
 </ul>';
 $lang['param_category'] = 'Lors de l&#039;utilisation <em>par d&eacute;faut</em> en mode sommaire, ce param&egrave;tre, qui devrait correspondre au nom d&#039;une cat&eacute;gorie existante, sera utilis&eacute; pour afficher seulement les entr&eacute;es qui sont dans cette cat&eacute;gorie (une liste s&eacute;par&eacute;e par des virgules peut &ecirc;tre fournie)';
 $lang['param_categorylisttemplate'] = 'Utile seulement avec l&#039;action categorylist, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
+$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'Sp&eacute;cifie l&#039;id ou l&#039;alias de la page qui doit &ecirc;tre utilis&eacute;e pour afficher le d&eacute;tail.';
 $lang['param_detailtemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit devrait &ecirc;tre utilis&eacute; pour l&#039;affichage en mode d&eacute;tails. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
+$lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
+$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Utilis&eacute; seulement avec l&#039;action 
 <em>default</em>, ce param&egrave;tre indique que seuls les produits appartenant &agrave; cet &eacute;l&eacute;ment de hi&eacute;rarchie doivent &ecirc;tre affich&eacute;s.  Des jokers peuvent &ecirc;tre utilis&eacute;s pour &eacute;tendre l&#039;affichage aux parent ou enfants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie indiqu&eacute;.  Par exemple {Products hierarchy=&#039;potirons*&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux descendants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;.  De m&ecirc;me, {Products hierarchy=&#039;*potirons&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux parents de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;';
 $lang['param_hierarchytemplate'] = 'Ce param&egrave;tre indique le gabarit &agrave; utiliser lors de l&#039;affichage de la hi&eacute;rarchie. Le gabarit de hi&eacute;rarchie par d&eacute;faut est utilis&eacute; si ce param&egrave;tre est absent ou vide.';
+$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
 $lang['param_pagelimit'] = 'Utilis&eacute; seulement avec l&#039;action <em>par d&eacute;faut</em>, ce param&egrave;tre sp&eacute;cifie combien d&#039;articles doivent &ecirc;tre list&eacute;s sur chaque page.';
 $lang['param_parent'] = 'Utilis&eacute; seulement avec l&#039;action <em>hierarchy</em>, ce param&egrave;tre indique quel est  l&#039;ID du premier &eacute;l&eacute;ment de la hi&eacute;rarchie &agrave; afficher';
 $lang['param_productid'] = 'Utilis&eacute; seulement avec l&#039;action d&eacute;tail, ce param&egrave;tre indique quels produits utiliser pour l&#039;affichage.';
+$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
+$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
+$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
+$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
 $lang['param_sortorder'] = 'Sp&eacute;cifie l&#039;ordre des champs tri&eacute;s en mode sommaire. Les valeurs possibles sont:
 <ul>
   <li><strong>asc</strong> -- Ordre ascendant</li>
@@ -222,6 +250,8 @@ $lang['param_sortby'] = 'Applicable seulement en mode sommaire, ce param&egrave;
   <li>created -- La date de cr&eacute;ation de l\&#039;entr&eacute;e</li>
   <li>modified --  La date de modification de l\&#039;entr&eacute;e</li>
 </ul>';
+$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
+$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
 $lang['param_summarytemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit doit &ecirc;tre utilis&eacute; en affichage mode sommaire. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
 $lang['parent'] = 'Parent ';
 $lang['postinstall'] = 'Le module Produits a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
@@ -233,13 +263,16 @@ $lang['price_adjustment'] = 'Ajustement de prix';
 $lang['prevpage'] = '&amp;lt;';
 $lang['product'] = 'Produit';
 $lang['productname'] = 'Nom du produit';
-$lang['products'] = 'Gestionnaire de Produits';
+$lang['products'] = 'Gestionnaire de produits';
+$lang['product_detail_settings'] = 'Param&egrave;tres D&eacute;tails du produit';
 $lang['product_hierarchy'] = 'Hierarchie de produits';
-$lang['product_manager'] = 'Gestionnaire de Produits';
+$lang['product_manager'] = 'Gestionnaire de produits';
 $lang['progress'] = 'Progression';
 $lang['prompt'] = 'Libell&eacute;';
+$lang['prompt_add_attribset'] = 'Ajouter/Modifier les param&egrave;tres des attributs';
 $lang['prompt_allowed_filetypes'] = 'Extensions de fichiers autoris&eacute;es (pour les champs de type fichier)';
 $lang['prompt_allowed_imagetypes'] = 'Extensions de fichiers image autoris&eacute;es (pour les champs de type image)';
+$lang['prompt_attribtemplate'] = 'Gabarit d&#039;affichage des valeurs d&#039;attributs de produits dans la liste d&eacute;roulante';
 $lang['prompt_autothumbnail'] = 'Cr&eacute;er automatiquement les miniatures des images';
 $lang['prompt_autothumbnail_size'] = 'Taille maximum (c&ocirc;t&eacute; le plus long) de la miniature.';
 $lang['prompt_autopreviewimg'] = 'Cr&eacute;er automatiquement une pr&eacute;visualisation de l&#039;image';
@@ -260,13 +293,28 @@ $lang['prompt_default_taxable'] = 'Tous les produits sont tax&eacute;s par d&eac
 $lang['prompt_deleteproductfiles'] = 'Effacer les fichiers attach&eacute;s au produit lors de sa suppression ?';
 $lang['prompt_delimiter'] = 'S&eacute;parateur de champs';
 $lang['prompt_detailpage'] = 'Page d&eacute;tail par d&eacute;faut';
+$lang['prompt_detailsfor'] = 'D&eacute;tails pour %s';
 $lang['prompt_duplicateproducts'] = 'Mode de gestion des produits en doublon ?';
+$lang['prompt_false'] = 'Faux';
 $lang['prompt_handleimages'] = 'G&eacute;rer les images ?';
 $lang['prompt_imagepath'] = 'Chemin des images';
+$lang['prompt_lengthunits'] = 'Unit&eacute;s de longueur';
+$lang['prompt_notfound_behavior'] = 'Quelle action doit &ecirc;tre r&eacute;alis&eacute;e lorsqu&#039;un produit ne peut &ecirc;tre affich&eacute;';
+$lang['prompt_notfound_404'] = 'G&eacute;n&eacute;rer une erreur 404';
+$lang['prompt_notfound_301'] = 'G&eacute;n&eacute;rer une redirection 301';
+$lang['prompt_notfound_errormsg'] = 'Afficher un message d&#039;erreur';
+$lang['prompt_notfound_msg'] = 'Message d&#039;erreur lorsqu&#039;un produit n&#039;est pas trouv&eacute;';
+$lang['prompt_notfound_page'] = 'Page pour faire les redirections permanantes';
+$lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits';
+$lang['prompt_products_matching'] = 'Produits correspondant &agrave; %s';
+$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
 $lang['prompt_summarysortorder'] = 'Ordre de tri par d&eacute;faut en mode sommaire';
 $lang['prompt_summarysorting'] = 'Champ de tri par d&eacute;faut en mode sommaire';
 $lang['prompt_template'] = 'Source du gabarit';
+$lang['prompt_true'] = 'Vrai';
 $lang['prompt_urlprefix'] = 'Pr&eacute;fixe &agrave; utiliser sur toutes les URL cibl&eacute;es de ce module';
+$lang['prompt_use_detailpage_for_search'] = 'Utiliser cette page pour les r&eacute;sultats de recherche<em>(remplace le param&egrave;tre &#039;page des r&eacute;sultats de la recherche&#039; dans le module search)</em>';
+$lang['prompt_usehierpathurls'] = 'Utiliser le &#039;Hierarchy Path&#039; dans les urls des d&eacute;tails de produit';
 $lang['prompt_weightunits'] = 'Unit&eacute;s de poids';
 $lang['public'] = 'Est-ce un champ public?';
 $lang['published'] = 'Publi&eacute;';
@@ -275,11 +323,29 @@ $lang['resettofactory'] = 'R&eacute;initialiser aux valeurs par d&eacute;faut';
 $lang['return'] = 'Retour';
 $lang['return_to_top'] = 'Retour en haut de page';
 $lang['root'] = 'Racine';
+$lang['search_description'] = 'Search Property Description';
+$lang['search_expr'] = 'La requ&ecirc;te devra elle correspondent &agrave; la totalit&eacute;, ou au moins &agrave; l&#039;un des tests ci-dessous?';
+$lang['search_name'] = 'Search Property Name';
+$lang['search_price'] = 'Gamme de prix';
+$lang['searchtemplate_addedit'] = 'Ajouter/Modifier le gabarit de formulaire de recherche';
+$lang['searchtemplates'] = 'Gabarit de recherche';
 $lang['select_one'] = 'Choisir...';
+$lang['sku'] = 'SKU (identifiant de quantit&eacute; en stock)';
 $lang['sort_by'] = 'Tri par';
 $lang['sort_order'] = 'Ordre de tri';
 $lang['status'] = 'Statut';
 $lang['submit'] = 'Soumettre';
+$lang['subscription'] = 'Abonnement';
+$lang['subscr_expiry'] = 'Expir&eacute;';
+$lang['subscr_expiry2'] = 'Expir&eacute;s';
+$lang['subscr_monthly'] = 'Mensuel';
+$lang['subscr_delperiod'] = 'Fr&eacute;quence de livraison';
+$lang['subscr_delperiod2'] = 'Livr&eacute;';
+$lang['subscr_payperiod'] = 'Fr&eacute;quence de paiement';
+$lang['subscr_payperiod2'] = 'Pay&eacute;';
+$lang['subscr_quarterly'] = 'Trimestriel';
+$lang['subscr_semianually'] = 'Semi-Annuel';
+$lang['subscr_yearly'] = 'Annuel';
 $lang['summarytemplates'] = 'Gabarits de sommaire';
 $lang['summarytemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit de sommaire';
 $lang['taxable'] = 'Taxable ';
@@ -289,19 +355,23 @@ $lang['textbox'] = 'Champ texte';
 $lang['title_byhierarchy_dflttemplate'] = 'Gabarit de hi&eacute;rarchie par d&eacute;faut';
 $lang['title_categorylist_dflttemplate'] = 'Gabarit par d&eacute;faut pour une nouvelle liste de cat&eacute;gories';
 $lang['title_detail_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;affichage du d&eacute;tail';
+$lang['title_search_dflttemplate'] = 'Gabarit par d&eacute;faut des Nouvelles recherches';
 $lang['title_summary_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;affichage du sommaire';
 $lang['type'] = 'Type ';
 $lang['update'] = 'Mise &agrave; jour';
 $lang['upload'] = 'Choisissez le fichier &agrave; envoyer';
+$lang['url_alias'] = 'URL Alias';
 $lang['valid'] = 'Valide';
 $lang['value'] = 'Valeur';
 $lang['values'] = 'Valeurs';
+$lang['view'] = 'Vue';
+$lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s &agrave; afficher dans le tableau';
 $lang['watermark_location'] = 'Emplacement du filigrane';
 $lang['weight'] = 'Poids';
 $lang['yes'] = 'Oui';
-$lang['utma'] = '156861353.3414768114938191000.1245249416.1254756487.1254830151.83';
-$lang['utmz'] = '156861353.1253885280.71.19.utmccn=(referral)|utmcsr=cmsmadesimple.fr|utmcct=/blog/index.php|utmcmd=referral';
-$lang['qca'] = '1245309559-39244215-61605127';
+$lang['qca'] = 'P0-1868798862-1289915740206';
+$lang['utmz'] = '156861353.1290510537.13.10.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['utma'] = '156861353.1598479872.1289915740.1290510537.1290517279.14';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1254830151';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
