@@ -198,7 +198,7 @@ class product_ops
     $done = false;
     if( $module->GetPreference('usehierpathurls',0) && !empty($product['alias']) && ($hier_id > 0) )
       {
-	$tmp = $module->GetHierarchyInfo($hier_id);
+	$tmp = product_ops::get_hierarchy_info($hier_id);
 	if( $tmp )
 	  {
 	    $tmp2 = explode(' | ',$tmp['long_name']);
@@ -241,15 +241,34 @@ class product_ops
   }
 
 
+  public static function get_product_hierarchy_id($productid)
+  {
+    $db = cmsms()->GetDb();
+  
+    $query = 'SELECT hierarchy_id FROM '.cms_db_prefix().'module_products_prodtohier
+              WHERE product_id = ? LIMIT 1';
+    $hier_id = $db->GetOne($query,array($productid));
+    return $hier_id;
+  }
+
+
+  public static function get_product_hierarchy_path($productid)
+  {
+    $hier_id = self::get_product_hierarchy_id($productid);
+    if( $hier_id )
+      return hierarchy_ops::get_hierarchy_path($hier_id);
+  }
+
+
   public static function create_hierarchy_breadcrumb($id,$product_id, $hierpage, $delim = ' &gt; ')
   {
     $module = self::_get_module();
     $tmp = array();
-    $hierarchy_path = $module->GetProductHierarchyPath($product_id);
+    $hierarchy_path = self::get_product_hierarchy_path($product_id);
     if( !$hierarchy_path ) return false;
     foreach( $hierarchy_path as $one )
       {
-	$info = $module->GetHierarchyInfo($one);
+	$info = hierarchy_ops::get_hierarchy_info($one);
 	$link = $module->CreatePrettyLink($id,'hierarchy',$hierpage,
 					  $info['name'],array('parent'=>$info['id']));
 	$tmp[] = $link;
